==> haskell-monad-par-0.3.4.8-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-IIEDpvqMNZYJw81Nysn4jI
key: monad-par-0.3.4.8-IIEDpvqMNZYJw81Nysn4jI
license: BSD3
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
author: Simon Marlow, Ryan Newton
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
abi: 13e90be8f42cdda8e575f8aeb6bfaccc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
data-dir: /usr/share/i386-linux-ghc-8.0.1/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-IIEDpvqMNZYJw81Nysn4jI
depends:
    abstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
    abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0 array-0.5.1.1
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    monad-par-extras-0.3.3-2svNFDzBzS82vbxGx9eHQm
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
    parallel-3.2.1.0-6VcN0yUHtcs831TgbJiSSi
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.4.8-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-3iD4If4zmfW4EvDI9ny1Id
key: monad-par-0.3.4.8-3iD4If4zmfW4EvDI9ny1Id
license: BSD3
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
author: Simon Marlow, Ryan Newton
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
abi: 147fa2db2871e9fd68a99e4b9d6be39a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
data-dir: /usr/share/i386-linux-ghc-8.0.1/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-3iD4If4zmfW4EvDI9ny1Id
depends:
    abstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
    abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0 array-0.5.1.1
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    monad-par-extras-0.3.3-2svNFDzBzS82vbxGx9eHQm
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.5.0-JV0Fije0tjpAZxTL84rKQ4
    parallel-3.2.1.1-JlIeVHTeCyBBNk1XJIPPlE
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
